@@ -91,6 +91,21 @@ def prepare_fields(fields, code):
 
     return fields_dict
 
+def prepare_template_fields(conf):
+    result = {}
+
+    set_if_not_equal(result, "name", conf.get("name", None), None)
+    set_if_not_equal(result, "templateType", conf.get("template_type", None), None)
+    set_if_not_equal(result, "agentType", conf.get("agent_type", None), None)
+    set_if_not_equal(result, "description", conf.get("description", None), None)
+    set_if_not_equal(result, "extension", conf.get("extension", None), None)
+    set_if_not_equal(result, "minReleaseLevel", conf.get("min_release", None), None)
+    set_if_not_equal(result, "variablePrefix", conf.get("var_prefix", None), None)
+    set_if_not_equal(result, "sysId", conf.get("sys_id", None), None)
+    set_if_not_equal(result, "scriptTypeWindows", conf.get("script_ext_windows", None), None)
+
+    return result
+
 
 def get_type_name(type):
     type = type.title()
@@ -305,7 +320,24 @@ def dump_fields(fields_json):
             field["raw"] = raw_items
         fields.append(field)
     
-    return {"fields": fields}
+    return fields
+
+
+def dump_template_fields(_json):
+    result = {}
+    set_if_not_equal(result, "name", _json["name"], None)
+    set_if_not_equal(result, "template_type", _json["templateType"], None)
+    set_if_not_equal(result, "agent_type", _json["agentType"], None)
+    set_if_not_equal(result, "description", _json["description"], None)
+    set_if_not_equal(result, "extension", _json["extension"], None)
+    set_if_not_equal(result, "min_release", _json["minReleaseLevel"], None)
+    set_if_not_equal(result, "var_prefix", _json["variablePrefix"], None)
+    set_if_not_equal(result, "sys_id", _json["sysId"], None)
+    set_if_not_equal(result, "script_ext_windows", _json["scriptTypeWindows"], None)
+
+
+    return result
+
 
 def new_uuid():
     return str(uuid.uuid4()).replace("-","")
