@@ -620,6 +620,8 @@ class Quip:
                 new_fields = conf.get("fields", [])
                 logging.debug("FIELDS: ", new_fields)
                 fields_dict = fb.prepare_fields(new_fields, code)
+                template_dict = fb.prepare_template_fields(conf)
+                template_dict["fields"] = fields_dict
             
             logging.info("Updating template.json file")
             template = self.join_path("src", "templates", "template.json")
@@ -627,9 +629,10 @@ class Quip:
                 with open(template, "r") as f:
                     template_content = f.read()
                     
+                _json = json.loads(template_content)
+                _json.update(template_dict)
+                
                 with open(template, "w") as f:
-                    _json = json.loads(template_content)
-                    _json["fields"] = fields_dict
                     f.write(self.format_json(_json))
                     logging.debug("template.json file is updated")
                 
@@ -649,8 +652,10 @@ class Quip:
             with open(template, "r") as f:
                 template_content = f.read()
                 _json = json.loads(template_content)
+                template_dict = fb.dump_template_fields(_json)
                 fields_dict = fb.dump_fields(_json.get("fields"))
-                yaml_dump = yaml.dump(fields_dict, Dumper=MyDumper, default_flow_style=False, sort_keys=False)
+                template_dict["fields"] = fields_dict
+                yaml_dump = yaml.dump(template_dict, Dumper=MyDumper, default_flow_style=False, sort_keys=False, width=1000)
                 if not write:
                     print(yaml_dump)
                 else:
@@ -802,7 +807,8 @@ class Quip:
         package_folder = self.join_path("dist", "package_build")
         for filename in os.listdir(package_folder):
             if filename.endswith("universal_template.zip"):
-                new_filename = filename.replace("universal_template.zip", f"universal_template_{version}.zip")
+                base_filename = "unv-tmplt-" + os.path.basename(filename).replace("_universal_template.zip", f"-{version}.zip").replace("_", " ")
+                new_filename = os.path.join(os.path.dirname(filename),  base_filename)
                 new_filepath = self.join_path("dist", "package_build", new_filename)
                 if os.path.exists(new_filepath):
                     shutil.move(self.join_path("dist", "package_build", filename), new_filepath)
